.. Copyright (C) 2017-2018 nickolas360 <contact@nickolas360.com>

.. This file is part of pyrcb2-docs, documentation for pyrcb2.

.. pyrcb2-docs is licensed under the GNU Lesser General Public License
   as published by the Free Software Foundation, either version 3 of
   the License, or (at your option) any later version.

.. As an additional permission under GNU GPL version 3 section 7, you
   may distribute non-source forms of pyrcb2-docs without the copy of
   the GNU GPL normally required by section 4, provided you include a
   URL through which recipients can obtain a copy of the Corresponding
   Source and the GPL at no charge.

.. pyrcb2-docs is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.

.. You should have received a copy of the GNU Lesser General Public License
   along with pyrcb2-docs.  If not, see <http://www.gnu.org/licenses/>.

.. currentmodule:: pyrcb2

Version 0.5
===========

Changelog
---------

.. _changelog-0.5.3:

0.5.3
~~~~~

* Fixed issues with reusing `IRCBot` objects.

.. _changelog-0.5.2:

0.5.2
~~~~~

* Fixed an issue where timed out calls to :meth:`IRCBot.wait_for` would cause
  exceptions to be thrown.

.. _changelog-0.5.1:

0.5.1
~~~~~

* Fixed a bug where the coroutine returned by :meth:`IRCBot.join` would time
  out when ``extended-join`` was enabled.
* Fixed the formatting of `WaitError` messages.

.. _changelog-0.5.0:

0.5.0
~~~~~

* The IRCv3 extension ``extended-join`` is now requested by default.
* Updated the Unicode grapheme break database.
